# gprint

gprint is a Python module that allows to print color on almost any terminal.


## How to import

```python
from gprint import *
```

## Errors and contact

> guillermo@guillerpsanchez.dev

Feel free to contact me at any time.